import type { CreateDifference } from "./types/CreateDifference.js";
import type { DeleteDifference } from "./types/DeleteDifference.js";
import type { UpdateDifference } from "./types/UpdateDifference.js";
/**
 * Function to compare a `left` and a `right` value.
 *
 * @category Difference
 * @remarks
 * This does a deep comparison and yields the differences found with a
 * descriptive object.
 * @example
 * ```typescript
 * compare({ left: "🟢", right: "🟢" }); // []
 * compare({ left: "🟢", right: "❌" }); // [{ kind: UPDATE, left: "🟢", right: "❌", path: [] }]
 * compare({ left: { foo: "🟢" }, right: { foo: "❌" } }); // [{ kind: UPDATE, left: "🟢", right: "❌", path: ["foo"] }]
 * ```
 * @see {@link CreateDifference}
 * @see {@link DeleteDifference}
 * @see {@link UpdateDifference}
 *
 * @param values Values to compare.
 */
export declare const compare: (values: {
	/**
	 * Left value to compare.
	 */
	readonly left?: unknown;
	/**
	 * Right value to compare.
	 */
	readonly right?: unknown;
}) => Generator<CreateDifference | DeleteDifference | UpdateDifference>;
